@@ -111,8 +111,8 @@ def vallado(k, r0, r, tof, short, numiter, rtol):
         raise RuntimeError("Cannot compute orbit, phase angle is 180 degrees")
 
     psi = 0.0
-    psi_low = -4 * np.pi ** 2
-    psi_up = 4 * np.pi ** 2
+    psi_low = -4 * np.pi**2
+    psi_up = 4 * np.pi**2
 
     count = 0
 
@@ -128,10 +128,13 @@ def vallado(k, r0, r, tof, short, numiter, rtol):
                     * (1.0 / c3(psi))
                     * (1.0 - norm_r0_times_norm_r * np.sqrt(c2(psi)) / A)
                 )
-                y = norm_r0_plus_norm_r + A * (psi * c3(psi) - 1) / c2(psi) ** 0.5
+                y = (
+                    norm_r0_plus_norm_r
+                    + A * (psi * c3(psi) - 1) / c2(psi) ** 0.5
+                )
 
         xi = np.sqrt(y / c2(psi))
-        tof_new = (xi ** 3 * c3(psi) + A * np.sqrt(y)) / np.sqrt(k)
+        tof_new = (xi**3 * c3(psi) + A * np.sqrt(y)) / np.sqrt(k)
 
         # Convergence check
         if np.abs((tof_new - tof) / tof) < rtol:
@@ -194,7 +197,9 @@ def izzo(k, r1, r2, tof, M, numiter, rtol):
 
     # Check collinearity of r1 and r2
     if not cross(r1, r2).any():
-        raise ValueError("Lambert solution cannot be computed for collinear vectors")
+        raise ValueError(
+            "Lambert solution cannot be computed for collinear vectors"
+        )
 
     # Chord
     c = r2 - r1
@@ -218,7 +223,7 @@ def izzo(k, r1, r2, tof, M, numiter, rtol):
     i_t1, i_t2 = cross(i_h, i_r1), cross(i_h, i_r2)  # Fixed from paper
 
     # Non dimensional time of flight
-    T = np.sqrt(2 * k / s ** 3) * tof
+    T = np.sqrt(2 * k / s**3) * tof
 
     # Find solutions
     xy = _find_xy(ll, T, M, numiter, rtol)
@@ -226,7 +231,7 @@ def izzo(k, r1, r2, tof, M, numiter, rtol):
     # Reconstruct
     gamma = np.sqrt(k * s / 2)
     rho = (r1_norm - r2_norm) / c_norm
-    sigma = np.sqrt(1 - rho ** 2)
+    sigma = np.sqrt(1 - rho**2)
 
     for x, y in xy:
         V_r1, V_r2, V_t1, V_t2 = _reconstruct(
@@ -255,7 +260,7 @@ def _find_xy(ll, T, M, numiter, rtol):
     assert T > 0  # Mistake in the original paper
 
     M_max = np.floor(T / pi)
-    T_00 = np.arccos(ll) + ll * np.sqrt(1 - ll ** 2)  # T_xM
+    T_00 = np.arccos(ll) + ll * np.sqrt(1 - ll**2)  # T_xM
 
     # Refine maximum number of revolutions if necessary
     if T < T_00 + M_max * pi and M_max > 0:
@@ -280,7 +285,7 @@ def _find_xy(ll, T, M, numiter, rtol):
 @jit
 def _compute_y(x, ll):
     """Computes y."""
-    return np.sqrt(1 - ll ** 2 * (1 - x ** 2))
+    return np.sqrt(1 - ll**2 * (1 - x**2))
 
 
 @jit
@@ -294,11 +299,11 @@ def _compute_psi(x, y, ll):
     if -1 <= x < 1:
         # Elliptic motion
         # Use arc cosine to avoid numerical errors
-        return np.arccos(x * y + ll * (1 - x ** 2))
+        return np.arccos(x * y + ll * (1 - x**2))
     elif x > 1:
         # Hyperbolic motion
         # The hyperbolic sine is bijective
-        return np.arcsinh((y - x * ll) * np.sqrt(x ** 2 - 1))
+        return np.arcsinh((y - x * ll) * np.sqrt(x**2 - 1))
     else:
         # Parabolic motion
         return 0.0
@@ -317,12 +322,12 @@ def _tof_equation_y(x, y, T0, ll, M):
         eta = y - ll * x
         S_1 = (1 - ll - x * eta) * 0.5
         Q = 4 / 3 * hyp2f1b(S_1)
-        T_ = (eta ** 3 * Q + 4 * ll * eta) * 0.5
+        T_ = (eta**3 * Q + 4 * ll * eta) * 0.5
     else:
         psi = _compute_psi(x, y, ll)
         T_ = np.divide(
-            np.divide(psi + M * pi, np.sqrt(np.abs(1 - x ** 2))) - x + ll * y,
-            (1 - x ** 2),
+            np.divide(psi + M * pi, np.sqrt(np.abs(1 - x**2))) - x + ll * y,
+            (1 - x**2),
         )
 
     return T_ - T0
@@ -331,19 +336,21 @@ def _tof_equation_y(x, y, T0, ll, M):
 @jit
 def _tof_equation_p(x, y, T, ll):
     # TODO: What about derivatives when x approaches 1?
-    return (3 * T * x - 2 + 2 * ll ** 3 * x / y) / (1 - x ** 2)
+    return (3 * T * x - 2 + 2 * ll**3 * x / y) / (1 - x**2)
 
 
 @jit
 def _tof_equation_p2(x, y, T, dT, ll):
-    return (3 * T + 5 * x * dT + 2 * (1 - ll ** 2) * ll ** 3 / y ** 3) / (1 - x ** 2)
+    return (3 * T + 5 * x * dT + 2 * (1 - ll**2) * ll**3 / y**3) / (
+        1 - x**2
+    )
 
 
 @jit
 def _tof_equation_p3(x, y, _, dT, ddT, ll):
-    return (7 * x * ddT + 8 * dT - 6 * (1 - ll ** 2) * ll ** 5 * x / y ** 5) / (
-        1 - x ** 2
-    )
+    return (
+        7 * x * ddT + 8 * dT - 6 * (1 - ll**2) * ll**5 * x / y**5
+    ) / (1 - x**2)
 
 
 @jit
@@ -371,12 +378,12 @@ def _initial_guess(T, ll, M):
     """Initial guess."""
     if M == 0:
         # Single revolution
-        T_0 = np.arccos(ll) + ll * np.sqrt(1 - ll ** 2) + M * pi  # Equation 19
-        T_1 = 2 * (1 - ll ** 3) / 3  # Equation 21
+        T_0 = np.arccos(ll) + ll * np.sqrt(1 - ll**2) + M * pi  # Equation 19
+        T_1 = 2 * (1 - ll**3) / 3  # Equation 21
         if T >= T_0:
             x_0 = (T_0 / T) ** (2 / 3) - 1
         elif T < T_1:
-            x_0 = 5 / 2 * T_1 / T * (T_1 - T) / (1 - ll ** 5) + 1
+            x_0 = 5 / 2 * T_1 / T * (T_1 - T) / (1 - ll**5) + 1
         else:
             # This is the real condition, which is not exactly equivalent
             # elif T_1 < T < T_0
@@ -417,7 +424,7 @@ def _halley(p0, T0, ll, tol, maxiter):
         fder3 = _tof_equation_p3(p0, y, T0, fder, fder2, ll)
 
         # Halley step (cubic)
-        p = p0 - 2 * fder * fder2 / (2 * fder2 ** 2 - fder * fder3)
+        p = p0 - 2 * fder * fder2 / (2 * fder2**2 - fder * fder3)
 
         if abs(p - p0) < tol:
             return p
@@ -446,8 +453,8 @@ def _householder(p0, T0, ll, M, tol, maxiter):
 
         # Householder step (quartic)
         p = p0 - fval * (
-            (fder ** 2 - fval * fder2 / 2)
-            / (fder * (fder ** 2 - fval * fder2) + fder3 * fval ** 2 / 6)
+            (fder**2 - fval * fder2 / 2)
+            / (fder * (fder**2 - fval * fder2) + fder3 * fval**2 / 6)
         )
 
         if abs(p - p0) < tol:
