@@ -37,11 +37,11 @@ def J2_perturbation(t0, state, k, J2, R):
     r_vec = state[:3]
     r = norm(r_vec)
 
-    factor = (3.0 / 2.0) * k * J2 * (R ** 2) / (r ** 5)
+    factor = (3.0 / 2.0) * k * J2 * (R**2) / (r**5)
 
-    a_x = 5.0 * r_vec[2] ** 2 / r ** 2 - 1
-    a_y = 5.0 * r_vec[2] ** 2 / r ** 2 - 1
-    a_z = 5.0 * r_vec[2] ** 2 / r ** 2 - 3
+    a_x = 5.0 * r_vec[2] ** 2 / r**2 - 1
+    a_y = 5.0 * r_vec[2] ** 2 / r**2 - 1
+    a_z = 5.0 * r_vec[2] ** 2 / r**2 - 3
     return np.array([a_x, a_y, a_z]) * r_vec * factor
 
 
@@ -72,12 +72,12 @@ def J3_perturbation(t0, state, k, J3, R):
     r_vec = state[:3]
     r = norm(r_vec)
 
-    factor = (1.0 / 2.0) * k * J3 * (R ** 3) / (r ** 5)
+    factor = (1.0 / 2.0) * k * J3 * (R**3) / (r**5)
     cos_phi = r_vec[2] / r
 
-    a_x = 5.0 * r_vec[0] / r * (7.0 * cos_phi ** 3 - 3.0 * cos_phi)
-    a_y = 5.0 * r_vec[1] / r * (7.0 * cos_phi ** 3 - 3.0 * cos_phi)
-    a_z = 3.0 * (35.0 / 3.0 * cos_phi ** 4 - 10.0 * cos_phi ** 2 + 1)
+    a_x = 5.0 * r_vec[0] / r * (7.0 * cos_phi**3 - 3.0 * cos_phi)
+    a_y = 5.0 * r_vec[1] / r * (7.0 * cos_phi**3 - 3.0 * cos_phi)
+    a_z = 3.0 * (35.0 / 3.0 * cos_phi**4 - 10.0 * cos_phi**2 + 1)
     return np.array([a_x, a_y, a_z]) * factor
 
 
@@ -193,7 +193,10 @@ def third_body(t0, state, k, k_third, perturbation_body):
     """
     body_r = perturbation_body(t0)
     delta_r = body_r - state[:3]
-    return k_third * delta_r / norm(delta_r) ** 3 - k_third * body_r / norm(body_r) ** 3
+    return (
+        k_third * delta_r / norm(delta_r) ** 3
+        - k_third * body_r / norm(body_r) ** 3
+    )
 
 
 def radiation_pressure(t0, state, k, R, C_R, A_over_m, Wdivc_s, star):
