@@ -60,8 +60,12 @@ def _targetting(departure_body, target_body, t_launch, t_arrival):
 
     # Transform into Orbit objects
     attractor = departure_body.parent
-    ss_dpt = Orbit.from_vectors(attractor, rr_dpt_body, vv_dpt_body, epoch=t_launch)
-    ss_arr = Orbit.from_vectors(attractor, rr_arr_body, vv_arr_body, epoch=t_arrival)
+    ss_dpt = Orbit.from_vectors(
+        attractor, rr_dpt_body, vv_dpt_body, epoch=t_launch
+    )
+    ss_arr = Orbit.from_vectors(
+        attractor, rr_arr_body, vv_arr_body, epoch=t_arrival
+    )
 
     # Define time of flight
     tof = ss_arr.epoch - ss_dpt.epoch
@@ -78,14 +82,14 @@ def _targetting(departure_body, target_body, t_launch, t_arrival):
         dv_arr = norm(man_lambert.impulses[1][1])
 
         # Compute all the output variables
-        c3_launch = dv_dpt ** 2
-        c3_arrival = dv_arr ** 2
+        c3_launch = dv_dpt**2
+        c3_arrival = dv_arr**2
 
         return (
             dv_dpt.to_value(u.km / u.s),
             dv_arr.to_value(u.km / u.s),
-            c3_launch.to_value(u.km ** 2 / u.s ** 2),
-            c3_arrival.to_value(u.km ** 2 / u.s ** 2),
+            c3_launch.to_value(u.km**2 / u.s**2),
+            c3_arrival.to_value(u.km**2 / u.s**2),
             tof.jd,
         )
 
@@ -138,7 +142,7 @@ class PorkchopPlotter:
         ax=None,
         tfl=True,
         vhp=True,
-        max_c3=45.0 * u.km ** 2 / u.s ** 2,
+        max_c3=45.0 * u.km**2 / u.s**2,
         max_vhp=5 * u.km / u.s,
     ):
         self.departure_body = departure_body
@@ -193,7 +197,9 @@ class PorkchopPlotter:
         else:
             fig = self.ax.figure
 
-        c3_levels = np.linspace(0, self.max_c3.to_value(u.km ** 2 / u.s ** 2), 30)
+        c3_levels = np.linspace(
+            0, self.max_c3.to_value(u.km**2 / u.s**2), 30
+        )
 
         c = self.ax.contourf(
             [D.to_datetime() for D in self.launch_span],
@@ -229,7 +235,9 @@ class PorkchopPlotter:
                 linewidths=3.5,
             )
 
-            self.ax.clabel(tfl_contour, inline=1, fmt="%1.1f", colors="r", fontsize=14)
+            self.ax.clabel(
+                tfl_contour, inline=1, fmt="%1.1f", colors="r", fontsize=14
+            )
 
         if self.vhp:
 
@@ -270,7 +278,7 @@ class PorkchopPlotter:
         return (
             dv_launch * u.km / u.s,
             dv_arrival * u.km / u.s,
-            c3_launch * u.km ** 2 / u.s ** 2,
-            c3_arrival * u.km ** 2 / u.s ** 2,
+            c3_launch * u.km**2 / u.s**2,
+            c3_arrival * u.km**2 / u.s**2,
             tof * u.d,
         )
