@@ -10,7 +10,7 @@ from poliastro.frames import Planes
 from poliastro.twobody.states import RVState
 
 u.kms = u.km / u.s
-u.km3s2 = u.km ** 3 / u.s ** 2
+u.km3s2 = u.km**3 / u.s**2
 
 
 def state_from_vector(func):
@@ -36,7 +36,10 @@ def state_from_vector(func):
     def wrapper(t, u_, k, *args, **kwargs):
         r, v = u_[:3], u_[3:]
         ss = RVState(
-            Body(None, k * u.km3s2, "_Dummy"), r * u.km, v * u.kms, Planes.EARTH_EQUATOR
+            Body(None, k * u.km3s2, "_Dummy"),
+            r * u.km,
+            v * u.kms,
+            Planes.EARTH_EQUATOR,
         )
 
         return func(t, ss, *args, **kwargs)
