@@ -122,7 +122,9 @@ class LatitudeCrossEvent(Event):
     def __call__(self, t, u_, k):
         self._last_t = t
         pos_on_body = (u_[:3] / norm(u_[:3])) * self._R
-        lat_, _, _ = cartesian_to_ellipsoidal_fast(self._R, self._R_polar, *pos_on_body)
+        lat_, _, _ = cartesian_to_ellipsoidal_fast(
+            self._R, self._R_polar, *pos_on_body
+        )
 
         return np.rad2deg(lat_) - self._lat
 
@@ -146,7 +148,7 @@ class EclipseEvent(Event):
         self._primary_body = orbit.attractor
         self._secondary_body = orbit.attractor.parent
         self._epoch = orbit.epoch
-        self.k = self._primary_body.k.to_value(u.km ** 3 / u.s ** 2)
+        self.k = self._primary_body.k.to_value(u.km**3 / u.s**2)
         self.R_sec = self._secondary_body.R.to_value(u.km)
         self.R_primary = self._primary_body.R.to_value(u.km)
 
@@ -278,7 +280,9 @@ class LosEvent(Event):
                 "The norm of the position vector of the primary body is less than the radius of the attractor."
             )
 
-        pos_coord = self._pos_coords.pop(0) if self._pos_coords else self._last_coord
+        pos_coord = (
+            self._pos_coords.pop(0) if self._pos_coords else self._last_coord
+        )
 
         # Need to cast `pos_coord` to array since `norm` inside numba only works for arrays, not lists.
         delta_angle = line_of_sight_fast(u_[:3], np.array(pos_coord), self._R)
